| expand_trade_sources | R Documentation |
Create a new dataframe where each row has a year range into one where each row is a single year, effectively 'expanding' the whole year range.
expand_trade_sources(trade_sources)
trade_sources |
A tibble dataframe where each row contains the year range. |
A tibble dataframe where each row corresponds to a single year for a given source.
trade_sources <- tibble::tibble(
Name = c("a", "b", "c"),
Trade = c("t1", "t2", "t3"),
Info_Format = c("year", "partial_series", "year"),
Timeline_Start = c(1, 1, 2),
Timeline_End = c(3, 4, 5),
Timeline_Freq = c(1, 1, 2),
`Imp/Exp` = "Imp",
SACO_link = NA,
)
expand_trade_sources(trade_sources)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.