| items_cbs | R Documentation |
Defines name/code correspondences for commodity balance sheet (CBS) items.
items_cbs
A tibble where each row corresponds to one CBS item. It contains the following columns:
item_cbs_code: A numeric code used to refer to the CBS item.
item_cbs_name: A natural language name for the item.
item_type: An ad-hoc grouping of items. This is a work in progress
evolving depending on our needs, so for now it only has two possible
values:
livestock: The CBS item represents a live animal.
other: Not any of the previous groups.
Inspired by FAOSTAT data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.