whep_list_file_versions: Input file versions

View source: R/input_files.R

whep_list_file_versionsR Documentation

Input file versions

Description

Lists all existing versions of an input file from whep_inputs.

Usage

whep_list_file_versions(file_alias)

Arguments

file_alias

Internal name of the requested file. You can find the possible values in the whep_inputs dataset.

Value

A tibble where each row is a version. For details about its format, see pins::pin_versions().

Examples

whep_list_file_versions("read_example")

whep documentation built on Nov. 5, 2025, 7:18 p.m.