Create a table with processes, their inputs (use) and their outputs (supply).
Value
A tibble with the supply and use data for processes. It contains the following columns:
year: The year in which the recorded event occurred.area_code: The code of the country where the data is from. For code details see e.g.add_area_name().proc_group: The type of process taking place. It can be one of:crop_production: Production of crops and their residues, e.g. rice production, coconut production, etc.husbandry: Animal husbandry, e.g. dairy cattle husbandry, non-dairy cattle husbandry, layers chickens farming, etc.animal_draught: Annual useful work energy generated by draft animals.slaughtering: Slaughter of live animals into meat, edible offals, raw animal fats, and hides/skins.processing: Derived subproducts obtained from processing other items. The items used as inputs are those that have a non-zero processing use in the commodity balance sheet. Seeget_wide_cbs()for more details. In each process there is a single input. In some processes like olive oil extraction or soyabean oil extraction this might make sense. Others like alcohol production need multiple inputs (e.g. multiple crops work), so in this data there would not be a process like alcohol production but rather a virtual process like 'Wheat and products processing', giving all its possible outputs. This is a constraint because of how the data was obtained and might be improved in the future. Seeget_processing_coefs()for more details.
proc_cbs_code: The code of the main item in the process taking place. Together withproc_group, these two columns uniquely represent a process. The main item is predictable depending on the value ofproc_group:crop_production: The code is from the item for which seed usage (if any) is reported in the commodity balance sheet, except for field co-products where the process uses the field aggregate item. For example, rice production uses the rice code, while seed cotton production uses the seed cotton code and supplies both cottonseed and cotton lint.husbandry: The code of the farmed animal, e.g. bees for beekeeping, non-dairy cattle for non-dairy cattle husbandry, etc.slaughtering: The code of the live animal being slaughtered, e.g. non-dairy cattle for cattle slaughter.processing: The code of the item that is used as input, i.e., the one that is processed to get other derived products. This uniquely defines a process within the group because of the nature of the data that was used, which you can see inget_processing_coefs().
For code details see e.g.
add_item_cbs_name().item_cbs_code: The code of the item produced or used in the process. Note that this might be the same value asproc_cbs_code, e.g., in rice production process for the row defining the amount of rice produced or the amount of rice seed as input, but it might also have a different value, e.g. for the row defining the amount of straw residue from rice production. For code details see e.g.add_item_cbs_name().type: Can have two values:use: The given item is an input of the process.supply: The given item is an output of the process.
value: Quantity in the item's own unit. Most items are measured in tonnes; live animals are measured in heads; animal draught is measured as annual useful work energy (TJ).
Examples
build_supply_use(example = TRUE)
#> # A tibble: 10 × 11
#> year area_code polity_area_code reporting_polity_code reporting_polity_name
#> <dbl> <dbl> <int> <chr> <chr>
#> 1 2021 255 255 BEL-1831-2025 Belgium
#> 2 2003 84 84 GRC-1919-2025 Greece
#> 3 1982 3 3 ALB-1913-2025 Albania (1913-2025)
#> 4 2000 8 8 ATG-1800-2025 Antigua and Barbuda
#> 5 2013 170 170 PER-1942-2025 Peru
#> 6 1985 75 75 GMB-1800-2025 Gambia
#> 7 1969 144 144 MOZ-1891-1975 Mozambique (1891-1975)
#> 8 2010 NA NA NA NA
#> 9 1998 115 115 KHM-1953-2025 Cambodia
#> 10 1967 238 238 ETH-1952-1993 Ethiopia (1952-1993)
#> # ℹ 6 more variables: reporting_polity_has_geometry <lgl>, proc_group <chr>,
#> # proc_cbs_code <dbl>, item_cbs_code <dbl>, type <chr>, value <dbl>