Learn R Programming

whep (version 0.3.0)

calculate_nue_crops: N soil inputs and Nitrogen Use Efficiency (NUE) for crop

Description

N inputs (deposition, fixation, synthetic fertilizers, urban sources, manure) and N production in Spain from 1860 to the present for the GRAFS model at the provincial level. The crop NUE is defined as the percentage of produced nitrogen relative to the total nitrogen inputs to the soil. Total soil inputs are calculated as: inputs = deposition + fixation + synthetic + manure + urban

Usage

calculate_nue_crops(example = FALSE)

Value

A tibble containing nitrogen use efficiency (NUE) for crops. It includes the following columns:

  • year: Year.

  • province_name: The Spanish province.

  • item: The item which was produced, defined in names_biomass_cb.

  • box: One of the two systems of the GRAFS model: cropland or semi-natural agroecosystems.

  • nue: Nitrogen Use Efficiency as a percentage (%).

Arguments

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
calculate_nue_crops(example = TRUE)

Run the code above in your browser using DataLab