Learn R Programming

whep (version 0.3.0)

calculate_nue_livestock: NUE for Livestock

Description

Calculates Nitrogen Use Efficiency (NUE) for livestock categories (excluding pets).

The livestock NUE is defined as the percentage of nitrogen in livestock products relative to the nitrogen in feed intake: nue = prod_n / feed_n * 100

Additionally, a mass balance is calculated to check the recovery of N in products and excretion relative to feed intake: mass_balance = (prod_n + excretion_n) / feed_n

Usage

calculate_nue_livestock(example = FALSE)

Value

A tibble containing:

  • year: Year

  • province_name: Spanish province

  • livestock_cat: Livestock category

  • item: Produced item

  • prod_n: Nitrogen in livestock products (Mg)

  • feed_n: Nitrogen in feed intake (Mg)

  • excretion_n: Nitrogen excreted (Mg)

  • nue: Nitrogen Use Efficiency (%)

  • mass_balance: Mass balance ratio (%)

Arguments

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
calculate_nue_livestock(example = TRUE)

Run the code above in your browser using DataLab