Calculates Nitrogen Use Efficiency (NUE) for livestock categories
(excluding pets).
The livestock NUE is defined as the percentage of nitrogen in livestock
products relative to the nitrogen in feed intake:
nue = prod_n / feed_n * 100
Additionally, a mass balance is calculated to check the recovery of N in
products and excretion relative to feed intake:
mass_balance = (prod_n + excretion_n) / feed_n