Learn R Programming

whep (version 0.3.0)

calculate_system_nue: System NUE

Description

Calculates the NUE for Spain at the provincial level. The system NUE is defined as the percentage of total nitrogen production (total_prod) relative to the sum of all nitrogen inputs (inputs) into the soil system.

Usage

calculate_system_nue(n_soil_inputs = create_n_soil_inputs(), example = FALSE)

Value

A tibble with the following columns:

  • year: Year

  • province_name: Spanish province

  • total_prod: Total nitrogen production (Mg)

  • inputs: Total nitrogen inputs (Mg)

  • nue_system: System-level Nitrogen Use Efficiency (%)

Arguments

n_soil_inputs

A tibble of nitrogen soil input (deposition, fixation, synthetic, manure, urban). If not provided and example = FALSE, it will be computed from create_n_soil_inputs().

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
calculate_system_nue(example = TRUE)

Run the code above in your browser using DataLab