Learn R Programming

whep (version 0.3.0)

create_n_nat_destiny: GRAFS Nitrogen (N) flows at Spain national level

Description

Provides N flows of the Spanish agro-food system on a national level between 1860 and 2020. This dataset is the national equivalent of the provincial GRAFS model and represents Spain as a single system without internal trade between provinces. All production, consumption and soil inputs are aggregated nationally before calculating trade with the outside.

Usage

create_n_nat_destiny(example = FALSE)

Value

A final tibble containing national N flow data by origin and destiny. It includes the following columns:

  • year: The year in which the recorded event occurred.

  • item: The item which was produced, defined in names_biomass_cb.

  • irrig_cat: Irrigation form (irrigated or rainfed)

  • box: One of the GRAFS model systems: cropland, Semi-natural agroecosystems, Livestock, Fish, or Agro-industry.

  • origin: The origin category of N: Cropland, Semi-natural agroecosystems, Livestock, Fish, Agro-industry, Deposition, Fixation, Synthetic, People (waste water), Livestock (manure).

  • destiny: The destiny category of N: population_food, population_other_uses, livestock_mono, livestock_rum (feed), export, Cropland (for N soil inputs).

  • mg_n: Nitrogen amount in megagrams (Mg).

  • province_name: Set to "Spain" for all national-level rows.

Arguments

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
create_n_nat_destiny(example = TRUE)

Run the code above in your browser using DataLab