Learn R Programming

whep (version 0.3.0)

create_n_production: N production for Spain

Description

Calculates N production at the provincial level in Spain. Production is derived from consumption, export, import, and other uses.

Usage

create_n_production(example = FALSE)

Value

A tibble containing:

  • year: Year

  • province_name: Spanish province

  • item: Product item

  • box: Ecosystem box

  • prod: Produced N (Mg)

Arguments

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
create_n_production(example = TRUE)

Run the code above in your browser using DataLab