powered by
Calculates N production at the provincial level in Spain. Production is derived from consumption, export, import, and other uses.
create_n_production(example = FALSE)
A tibble containing:
year: Year
year
province_name: Spanish province
province_name
item: Product item
item
box: Ecosystem box
box
prod: Produced N (Mg)
prod
If TRUE, return a small example output without downloading remote data. Default is FALSE.
TRUE
FALSE
create_n_production(example = TRUE)
Run the code above in your browser using DataLab