Learn R Programming

whep (version 0.3.0)

create_n_soil_inputs: Nitrogen (N) soil inputs for Spain

Description

Calculates total nitrogen inputs to soils in Spain at the provincial level. This includes contributions from:

  • Atmospheric deposition (deposition)

  • Biological nitrogen fixation (fixation)

  • Synthetic fertilizers (synthetic)

  • Manure (excreta, solid, liquid) (manure)

  • Urban sources (urban)

Special land use categories and items are aggregated:

  • Semi-natural agroecosystems (e.g., Dehesa, Pasture_Shrubland)

  • Firewood biomass (e.g., Conifers, Holm oak)

Usage

create_n_soil_inputs(example = FALSE)

Value

A tibble containing:

  • year: Year

  • province_name: Spanish province

  • item: Crop, land use, or biomass item

  • irrig_cat: Irrigation form (irrigated or rainfed)

  • box: Land use or ecosystem box for aggregation

  • deposition: N input from atmospheric deposition (Mg)

  • fixation: N input from biological N fixation (Mg)

  • synthetic: N input from synthetic fertilizers (Mg)

  • manure: N input from livestock manure (Mg)

  • urban: N input from urban sources (Mg)

Arguments

example

If TRUE, return a small example output without downloading remote data. Default is FALSE.

Examples

Run this code
create_n_soil_inputs(example = TRUE)

Run the code above in your browser using DataLab