Returns the periodized polity database, including geometry. Pass
polity_codes to retrieve a subset that can be joined to outputs from
add_polity_code().
Returns the periodized polity database, including geometry. Pass
polity_codes to retrieve a subset that can be joined to outputs from
add_polity_code().