| get_primary_production | R Documentation |
Get amount of crops, livestock and livestock products.
get_primary_production(version = NULL)
version |
File version to use as input. See whep_inputs for details. |
A tibble with the item production data. It contains the following columns:
year: The year in which the recorded event occurred.
area_code: The code of the country where the data is from. For code
details see e.g. add_area_name().
item_prod_code: FAOSTAT internal code for each produced item.
item_cbs_code: FAOSTAT internal code for each commodity balance sheet
item. The commodity balance sheet contains an aggregated version of
production items. This field is the code for the corresponding
aggregated item.
live_anim_code: Commodity balance sheet code for the type of livestock
that produces the livestock product. It can be:
NA: The entry is not a livestock product.
Non-NA: The code for the livestock type. The name can also be
retrieved by using add_item_cbs_name().
unit: Measurement unit for the data. Here, keep in mind three groups of
items: crops (e.g. Apples and products, Beans...), livestock (e.g.
Cattle, dairy, Goats...) and livestock products (e.g. Poultry Meat, Offals, Edible...). Then the unit can be one of:
tonnes: Available for crops and livestock products.
ha: Hectares, available for crops.
t_ha: Tonnes per hectare, available for crops.
heads: Number of animals, available for livestock.
LU: Standard Livestock Unit measure, available for livestock.
t_head: tonnes per head, available for livestock products.
t_LU: tonnes per Livestock Unit, available for livestock products.
value: The amount of item produced, measured in unit.
# Note: These are smaller samples to show outputs, not the real data.
# For all data, call the function with default version (i.e. no arguments).
get_primary_production(version = "example")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.