year: The year in which the recorded event occurred.
area_code: The code of the country where the data is from. For code
details see e.g. add_area_name().
item_cbs_code_crop: FAOSTAT internal code for each commodity balance
sheet item. This is the crop that is generating the residue.
item_cbs_code_residue: FAOSTAT internal code for each commodity balance
sheet item. This is the obtained residue. In the commodity balance sheet,
this can be three different items right now:
These are actually not FAOSTAT defined items, but custom defined by us.
When necessary, FAOSTAT codes are extended for our needs.
value: The amount of residue produced, measured in tonnes.