| whep_read_file | R Documentation |
Used to fetch input files that are needed for the package's functions and that were built in external sources and are too large to include directly. This is a public function for transparency purposes, so that users can inspect the original inputs of this package that were not directly processed here.
If the requested file doesn't exist locally, it is downloaded from a public
link and cached before reading it. This is all implemented using the
pins package. It supports multiple
file formats and file versioning.
whep_read_file(file_alias, type = "parquet", version = NULL)
file_alias |
Internal name of the requested file. You can find the
possible values in the |
type |
The extension of the file that must be read. Possible values:
Saving each file in both formats is for transparency and accessibility
purposes, e.g., having to share the data with non-programmers who can
easily import a CSV into a spreadsheet. You will most likely never have
to set this option manually unless for some reason a file could not be
supplied in e.g. |
version |
The version of the file that must be read. Possible values:
|
A tibble with the dataset. Some information about each dataset can be found in the code where it's used as input for further processing.
whep_read_file("read_example")
whep_read_file("read_example", type = "parquet", version = "latest")
whep_read_file(
"read_example",
type = "csv",
version = "20250721T152646Z-ce61b"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.